# Statistical Tests

This module allows us to apply different statistical tests.

::: probatus.stat_tests.distribution_statistics

## Available tests
- [Anderson-Darling (ad)][probatus.stat_tests.ad.ad]
- [Epps-Singleton (es)][probatus.stat_tests.es.es]
- [Kolmogorov-Smirnov (ks)][probatus.stat_tests.ks.ks]
- [Population Stability Index (psi)][probatus.stat_tests.psi.psi]
- [Shapiro-Wilk (sw)][probatus.stat_tests.sw.sw]

::: probatus.stat_tests.ad
::: probatus.stat_tests.es
::: probatus.stat_tests.ks
::: probatus.stat_tests.psi
::: probatus.stat_tests.sw
